@@ -184,8 +184,8 @@ class MQ(object):
                 to_dashboard = False
                 connections = graph.getOutputConnections(g.nodeId, port_id)
                 for tgt in connections:
-                    node = graph.getNodeById(tgt.process)
-                    if node.metadata['def'].type in [22, 10002]:
+                    tgt_node = graph.getNodeById(tgt.process)
+                    if tgt_node.metadata['def'].type in [22, 10002]:
                         to_dashboard = True
                         break
 
@@ -193,8 +193,8 @@ class MQ(object):
 
     def _sendP2PMessages(self, queue, data):
         send_master = False
-        for port_id, connections in self._outputConnections.items():
-            to_dashboard, connections = connections
+        for port_id, conns in self._outputConnections.items():
+            to_dashboard, connections = conns
             send_master = send_master or to_dashboard
             if not to_dashboard:
                 for tgt in connections:
@@ -206,7 +206,8 @@ class MQ(object):
                             data4in["extra"] = extra
                         target_queue = f'{queue}-{tgt.process}'
                         yield target_queue, data4in
-                        data.pop(port_id, None)
+
+                data.pop(port_id, None)
 
         if send_master:
             # connection to dashboard, data must send to master
